# File-Organizer
A script that scans throught the current directory and organizes all loose files into folders


## Commands

* safe
* all
* images
* audios
* videos
* office
* vectors
* gifs
* photoshop
* pdfs
* fonts
* code

## Instal
```python
pip install Organizer
```

## Usage 
```text
Organizer image     # Organizes all image files
```
```text
Organizer video     # Organizes all video files
```
```text
Organizer audio     # Organizes all audio files
```
```text
Organizer pdf       # Organizes all pdf files
```
```text
Organizer all       # Organizes all supported files
```